package com.jjt.inventory.mapper;

import java.util.List;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.jjt.inventory.domain.TwinCalcDayPt;

/**
 * 盘头库日统计数据Mapper接口
 *
 * @author wukai
 * @date 2025-06-13
 */
public interface TwinCalcDayPtMapper extends BaseMapper<TwinCalcDayPt>
{
    /**
     * 查询盘头库日统计数据
     *
     * @param id 盘头库日统计数据主键
     * @return 盘头库日统计数据
     */
    public TwinCalcDayPt selectTwinCalcDayPtById(Long id);

    /**
     * 查询盘头库日统计数据列表
     *
     * @param twinCalcDayPt 盘头库日统计数据
     * @return 盘头库日统计数据集合
     */
    public List<TwinCalcDayPt> selectTwinCalcDayPtList(TwinCalcDayPt twinCalcDayPt);

    /**
     * 新增盘头库日统计数据
     *
     * @param twinCalcDayPt 盘头库日统计数据
     * @return 结果
     */
    public int insertTwinCalcDayPt(TwinCalcDayPt twinCalcDayPt);

    /**
     * 修改盘头库日统计数据
     *
     * @param twinCalcDayPt 盘头库日统计数据
     * @return 结果
     */
    public int updateTwinCalcDayPt(TwinCalcDayPt twinCalcDayPt);

    /**
     * 删除盘头库日统计数据
     *
     * @param id 盘头库日统计数据主键
     * @return 结果
     */
    public int deleteTwinCalcDayPtById(Long id);

    /**
     * 批量删除盘头库日统计数据
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteTwinCalcDayPtByIds(Long[] ids);
    /**
     * 删除白坯库日统计数据信息
     *
     * @param date 白坯库日统计数据主键
     */
    void delete4date(String date);
}
