package com.jjt.inventory.controller;

import java.util.List;
import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.jjt.common.annotation.Log;
import com.jjt.common.core.controller.BaseController;
import com.jjt.common.core.domain.AjaxResult;
import com.jjt.common.enums.BusinessType;
import com.jjt.inventory.domain.TwinCalcDayPt;
import com.jjt.inventory.service.ITwinCalcDayPtService;
import com.jjt.common.utils.poi.ExcelUtil;
import com.jjt.common.core.page.TableDataInfo;

/**
 * 盘头库日统计数据Controller
 *
 * @author wukai
 * @date 2025-06-13
 */
@Api(tags="盘头库日统计数据")
@RestController
@RequestMapping("/inventory/ptDay")
public class TwinCalcDayPtController extends BaseController{
    @Resource
    private ITwinCalcDayPtService twinCalcDayPtService;

    /**
     * 查询盘头库日统计数据列表
     */
    @ApiOperation("查询盘头库日统计数据列表")
    //@PreAuthorize("@ss.hasPermi('inventory:ptDay:list')")
    @GetMapping("/list")
    public TableDataInfo list(TwinCalcDayPt twinCalcDayPt)
    {
        startPage();
        List<TwinCalcDayPt> list = twinCalcDayPtService.selectTwinCalcDayPtList(twinCalcDayPt);
        return getDataTable(list);
    }

    /**
     * 导出盘头库日统计数据列表
     */
    @ApiOperation("导出盘头库日统计数据列表")
    //@PreAuthorize("@ss.hasPermi('inventory:ptDay:export')")
    @Log(title = "盘头库日统计数据", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TwinCalcDayPt twinCalcDayPt)
    {
        List<TwinCalcDayPt> list = twinCalcDayPtService.selectTwinCalcDayPtList(twinCalcDayPt);
        ExcelUtil<TwinCalcDayPt> util = new ExcelUtil<TwinCalcDayPt>(TwinCalcDayPt.class);
        util.exportExcel(response, list, "盘头库日统计数据数据");
    }

    /**
     * 获取盘头库日统计数据详细信息
     */
    @ApiOperation("获取盘头库日统计数据详细信息")
    //@PreAuthorize("@ss.hasPermi('inventory:ptDay:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(twinCalcDayPtService.selectTwinCalcDayPtById(id));
    }

    /**
     * 新增盘头库日统计数据
     */
    @ApiOperation("新增盘头库日统计数据")
    //@PreAuthorize("@ss.hasPermi('inventory:ptDay:add')")
    @Log(title = "盘头库日统计数据", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TwinCalcDayPt twinCalcDayPt)
    {
        return toAjax(twinCalcDayPtService.insertTwinCalcDayPt(twinCalcDayPt));
    }

    /**
     * 修改盘头库日统计数据
     */
    @ApiOperation("修改盘头库日统计数据")
    //@PreAuthorize("@ss.hasPermi('inventory:ptDay:edit')")
    @Log(title = "盘头库日统计数据", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TwinCalcDayPt twinCalcDayPt)
    {
        return toAjax(twinCalcDayPtService.updateTwinCalcDayPt(twinCalcDayPt));
    }

    /**
     * 删除盘头库日统计数据
     */
    @ApiOperation("删除盘头库日统计数据")
    //@PreAuthorize("@ss.hasPermi('inventory:ptDay:remove')")
    @Log(title = "盘头库日统计数据", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(twinCalcDayPtService.deleteTwinCalcDayPtByIds(ids));
    }
}
